@@ -23,8 +23,6 @@
 Show diagnostic information
 """
 
-from __future__ import absolute_import
-
 import bleachbit
 
 import locale
@@ -39,7 +37,7 @@ if 'nt' == os.name:
 def diagnostic_info():
     """Return diagnostic information as a string"""
     # this section is for application and library versions
-    s = u"BleachBit version %s" % bleachbit.APP_VERSION
+    s = "BleachBit version %s" % bleachbit.APP_VERSION
 
     try:
         # Linux tarball will have a revision but not build_number
@@ -53,16 +51,20 @@ def diagnostic_info():
     except:
         pass
     try:
+        import gi
+        gi.require_version('Gtk', '3.0')
         from gi.repository import Gtk
         s += '\nGTK version {0}.{1}.{2}'.format(
             Gtk.get_major_version(), Gtk.get_minor_version(), Gtk.get_micro_version())
+        s += '\nGTK theme = %s' % Gtk.Settings.get_default().get_property('gtk-theme-name')
+        s += '\nGTK icon theme = %s' % Gtk.Settings.get_default().get_property('gtk-icon-theme-name')
+        s += '\nGTK prefer dark theme = %s' % Gtk.Settings.get_default().get_property('gtk-application-prefer-dark-theme')
     except:
         pass
     import sqlite3
     s += "\nSQLite version %s" % sqlite3.sqlite_version
 
     # this section is for variables defined in __init__.py
-    s += "\nFSE = %s" % bleachbit.FSE
     s += "\nlocal_cleaners_dir = %s" % bleachbit.local_cleaners_dir
     s += "\nlocale_dir = %s" % bleachbit.locale_dir
     s += "\noptions_dir = %s" % bleachbit.options_dir
@@ -77,18 +79,10 @@ def diagnostic_info():
         envs = ('APPDATA', 'cd', 'LocalAppData', 'LocalAppDataLow', 'Music',
                 'USERPROFILE', 'ProgramFiles', 'ProgramW6432', 'TMP')
     for env in envs:
-        if os.getenv(env):
-            s += "\nos.getenv('%s') = %s" % (env,
-                                             os.getenv(env).decode(bleachbit.FSE))
-        else:
-            s += "\nos.getenv('%s') = %s" % (env, os.getenv(env))
-    s += "\nos.path.expanduser('~') = %s" % bleachbit.expanduser('~')
+        s += "\nos.getenv('%s') = %s" % (env, os.getenv(env))
+    s += "\nos.path.expanduser('~') = %s" % os.path.expanduser('~')
     if sys.platform.startswith('linux'):
-        if hasattr(platform, 'linux_distribution'):
-            s += "\nplatform.linux_distribution() = %s" % str(
-                platform.linux_distribution())
-        else:
-            s += "\nplatform.dist() = %s" % str(platform.dist())
+        s += "\nplatform.linux_distribution() = %s" % str(platform.linux_distribution())
 
     # Mac Version Name - Dictionary
     macosx_dict = {'5': 'Leopard', '6': 'Snow Leopard', '7': 'Lion', '8': 'Mountain Lion',
@@ -101,7 +95,7 @@ def diagnostic_info():
                     s += "\nplatform.mac_ver() = %s" % str(
                         platform.mac_ver()[0] + " (" + macosx_dict[key] + ")")
         else:
-            s += "\nplatform.dist() = %s" % str(platform.dist())
+            s += "\nplatform.dist() = %s" % str(platform.linux_distribution(full_distribution_name=0))
 
     if 'nt' == os.name:
         s += "\nplatform.win32_ver[1]() = %s" % platform.win32_ver()[1]
