@@ -23,8 +23,6 @@
 Integration specific to Unix-like operating systems
 """
 
-from __future__ import absolute_import
-
 import bleachbit
 from bleachbit import FileUtilities, General
 from bleachbit import _
@@ -39,6 +37,10 @@ import sys
 
 logger = logging.getLogger(__name__)
 
+try:
+    Pattern = re.Pattern
+except AttributeError:
+    Pattern = re._pattern_type
 
 class LocaleCleanerPath:
     """This represents a path with either a specific folder name or a folder name pattern.
@@ -70,7 +72,7 @@ class LocaleCleanerPath:
     def get_subpaths(self, basepath):
         """Returns direct subpaths for this object, i.e. either the named subfolder or all
         subfolders matching the pattern"""
-        if isinstance(self.pattern, re._pattern_type):
+        if isinstance(self.pattern, Pattern):
             return (os.path.join(basepath, p) for p in os.listdir(basepath)
                     if self.pattern.match(p) and os.path.isdir(os.path.join(basepath, p)))
         else:
@@ -84,7 +86,7 @@ class LocaleCleanerPath:
                 if isinstance(child, LocaleCleanerPath):
                     for res in child.get_localizations(path):
                         yield res
-                elif isinstance(child, re._pattern_type):
+                elif isinstance(child, Pattern):
                     for element in os.listdir(path):
                         match = child.match(element)
                         if match is not None:
@@ -615,7 +617,8 @@ def apt_autoremove():
 
     args = ['--yes', 'autoremove']
     # After this operation, 74.7MB disk space will be freed.
-    freed_space_regex = r', ([\d.]+[a-zA-Z]{2}) disk space will be freed'
+    # After this operation, 44.0 kB disk space will be freed.
+    freed_space_regex = r'.*, ([\d.]+ ?[a-zA-Z]{2}) disk space will be freed.'
     try:
         return run_cleaner_cmd('apt-get', args, freed_space_regex, ['^E: '])
     except subprocess.CalledProcessError as e:
