@@ -37,8 +37,6 @@ These are the terms:
 
 """
 
-from __future__ import absolute_import
-
 import bleachbit
 from bleachbit import Command, FileUtilities, General
 
@@ -51,7 +49,7 @@ import sys
 from decimal import Decimal
 
 if 'win32' == sys.platform:
-    import _winreg
+    import winreg
     import pywintypes
     import win32api
     import win32con
@@ -120,7 +118,7 @@ def browse_folder(_, title):
     if pidl is None:
         # user cancelled
         return None
-    fullpath = shell.SHGetPathFromIDList(pidl)
+    fullpath = shell.SHGetPathFromIDListW(pidl)
     return fullpath
 
 
@@ -153,8 +151,8 @@ def delete_registry_value(key, value_name, really_delete):
     (hive, sub_key) = split_registry_key(key)
     if really_delete:
         try:
-            hkey = _winreg.OpenKey(hive, sub_key, 0, _winreg.KEY_SET_VALUE)
-            _winreg.DeleteValue(hkey, value_name)
+            hkey = winreg.OpenKey(hive, sub_key, 0, winreg.KEY_SET_VALUE)
+            winreg.DeleteValue(hkey, value_name)
         except WindowsError as e:
             if e.winerror == 2:
                 # 2 = 'file not found' means value does not exist
@@ -163,8 +161,8 @@ def delete_registry_value(key, value_name, really_delete):
         else:
             return True
     try:
-        hkey = _winreg.OpenKey(hive, sub_key)
-        _winreg.QueryValueEx(hkey, value_name)
+        hkey = winreg.OpenKey(hive, sub_key)
+        winreg.QueryValueEx(hkey, value_name)
     except WindowsError as e:
         if e.winerror == 2:
             return False
@@ -182,7 +180,7 @@ def delete_registry_key(parent_key, really_delete):
     (hive, parent_sub_key) = split_registry_key(parent_key)
     hkey = None
     try:
-        hkey = _winreg.OpenKey(hive, parent_sub_key)
+        hkey = winreg.OpenKey(hive, parent_sub_key)
     except WindowsError as e:
         if e.winerror == 2:
             # 2 = 'file not found' happens when key does not exist
@@ -192,23 +190,23 @@ def delete_registry_key(parent_key, really_delete):
     if not hkey:
         # key not found
         return False
-    keys_size = _winreg.QueryInfoKey(hkey)[0]
+    keys_size = winreg.QueryInfoKey(hkey)[0]
     child_keys = []
     for i in range(keys_size):
-        child_keys.append(parent_key + '\\' + _winreg.EnumKey(hkey, i))
+        child_keys.append(parent_key + '\\' + winreg.EnumKey(hkey, i))
     for child_key in child_keys:
         delete_registry_key(child_key, True)
-    _winreg.DeleteKey(hive, parent_sub_key)
+    winreg.DeleteKey(hive, parent_sub_key)
     return True
 
 
 def delete_updates():
     """Returns commands for deleting Windows Updates files"""
-    windir = bleachbit.expandvars('$windir')
+    windir = os.path.expandvars('$windir')
     dirs = glob.glob(os.path.join(windir, '$NtUninstallKB*'))
-    dirs += [bleachbit.expandvars('$windir\\SoftwareDistribution\\Download')]
-    dirs += [bleachbit.expandvars('$windir\\ie7updates')]
-    dirs += [bleachbit.expandvars('$windir\\ie8updates')]
+    dirs += [os.path.expandvars('$windir\\SoftwareDistribution\\Download')]
+    dirs += [os.path.expandvars('$windir\\ie7updates')]
+    dirs += [os.path.expandvars('$windir\\ie8updates')]
     if not dirs:
         # if nothing to delete, then also do not restart service
         return
@@ -244,7 +242,7 @@ def detect_registry_key(parent_key):
     (hive, parent_sub_key) = split_registry_key(parent_key)
     hkey = None
     try:
-        hkey = _winreg.OpenKey(hive, parent_sub_key)
+        hkey = winreg.OpenKey(hive, parent_sub_key)
     except WindowsError as e:
         if e.winerror == 2:
             # 2 = 'file not found' happens when key does not exist
@@ -260,23 +258,13 @@ def elevate_privileges():
     privileges.  If successful, return True (so original process
     can exit).  If failed or not applicable, return False."""
 
-    if parse_windows_build() < 6:
-        # Windows XP does not have the UAC.
-        # Vista is the first version Windows that has the UAC.
-        # 5.1 = Windows XP
-        # 6.0 = Vista
-        # 6.1 = 7
-        # 6.2 = 8
-        # 10 = 10
-        return False
-
     if shell.IsUserAnAdmin():
         logger.debug('already an admin (UAC not required)')
         return False
 
     if hasattr(sys, 'frozen'):
         # running frozen in py2exe
-        exe = sys.executable.decode(sys.getfilesystemencoding())
+        exe = sys.executable
         parameters = "--gui --no-uac"
     else:
         pyfile = os.path.join(bleachbit.bleachbit_exe_path, 'bleachbit.py')
@@ -356,7 +344,7 @@ def get_fixed_drives():
             # and free_space() returns access denied.
             # https://bugs.launchpad.net/bleachbit/+bug/1474848
             if os.path.isdir(drive):
-                yield unicode(drive)
+                yield drive
 
 
 def get_known_folder_path(folder_name):
@@ -450,72 +438,12 @@ def is_junction(path):
     so this is needed
     """
     FILE_ATTRIBUTE_REPARSE_POINT = 0x400
-    if isinstance(path, unicode):
-        attr = windll.kernel32.GetFileAttributesW(path)
-    else:
-        attr = windll.kernel32.GetFileAttributesA(path)
+    attr = windll.kernel32.GetFileAttributesW(path)
     return bool(attr & FILE_ATTRIBUTE_REPARSE_POINT)
 
 
+
 def is_process_running(name):
-    """Return boolean whether process (like firefox.exe) is running"""
-
-    if parse_windows_build() >= 6:
-        return is_process_running_psutil(name)
-    else:
-        # psutil does not support XP, so fall back
-        # https://github.com/giampaolo/psutil/issues/348
-        return is_process_running_win32(name)
-
-
-def is_process_running_win32(name):
-    """Return boolean whether process (like firefox.exe) is running
-
-    Does not work on 64-bit Windows
-
-    Originally by Eric Koome
-    license GPL
-    http://code.activestate.com/recipes/305279/
-    """
-
-    hModule = c_ulong()
-    count = c_ulong()
-    modname = c_buffer(30)
-    PROCESS_QUERY_INFORMATION = 0x0400
-    PROCESS_VM_READ = 0x0010
-
-    for pid in win32process.EnumProcesses():
-
-        # Get handle to the process based on PID
-        hProcess = kernel.OpenProcess(
-            PROCESS_QUERY_INFORMATION | PROCESS_VM_READ,
-            False, pid)
-        if hProcess:
-            psapi.EnumProcessModules(
-                hProcess, byref(hModule), sizeof(hModule), byref(count))
-            psapi.GetModuleBaseNameA(
-                hProcess, hModule.value, modname, sizeof(modname))
-            clean_modname = "".join(
-                [i for i in modname if i != '\x00']).lower()
-
-            # Clean up
-            for i in range(modname._length_):
-                modname[i] = '\x00'
-
-            kernel.CloseHandle(hProcess)
-
-            if len(clean_modname) > 0 and '?' != clean_modname:
-                # Filter out non-ASCII characters which we don't need
-                # and which may cause display warnings
-                clean_modname2 = re.sub(
-                    r'[^a-z.]', '_', clean_modname.lower())
-                if clean_modname2 == name.lower():
-                    return True
-
-    return False
-
-
-def is_process_running_psutil(name):
     """Return boolean whether process (like firefox.exe) is running
 
     Works on Windows Vista or later, but on Windows XP gives an ImportError
@@ -573,8 +501,7 @@ def set_environ(varname, path):
     if varname in os.environ:
         #logger.debug('set_environ(%s, %s): skipping because environment variable is already defined', varname, path)
         if 'nt' == os.name:
-            os.environ[varname] = bleachbit.expandvars(
-                u'%%%s%%' % varname).encode('utf-8')
+            os.environ[varname] = os.path.expandvars('%%%s%%' % varname)
         # Do not redefine the environment variable when it already exists
         # But re-encode them with utf-8 instead of mbcs
         return
@@ -582,8 +509,7 @@ def set_environ(varname, path):
         if not os.path.exists(path):
             raise RuntimeError(
                 'Variable %s points to a non-existent path %s' % (varname, path))
-        os.environ[varname] = path if isinstance(
-            path, str) else path.encode('utf8')
+        os.environ[varname] = path
     except:
         logger.exception(
             'set_environ(%s, %s): exception when setting environment variable', varname, path)
@@ -619,10 +545,10 @@ def split_registry_key(full_key):
     assert len(full_key) >= 6
     [k1, k2] = full_key.split("\\", 1)
     hive_map = {
-        'HKCR': _winreg.HKEY_CLASSES_ROOT,
-        'HKCU': _winreg.HKEY_CURRENT_USER,
-        'HKLM': _winreg.HKEY_LOCAL_MACHINE,
-        'HKU': _winreg.HKEY_USERS}
+        'HKCR': winreg.HKEY_CLASSES_ROOT,
+        'HKCU': winreg.HKEY_CURRENT_USER,
+        'HKLM': winreg.HKEY_LOCAL_MACHINE,
+        'HKU': winreg.HKEY_USERS}
     if k1 not in hive_map:
         raise RuntimeError("Invalid Windows registry hive '%s'" % k1)
     return hive_map[k1], k2
