@@ -22,31 +22,38 @@
 Code that is commonly shared throughout BleachBit
 """
 
-from __future__ import absolute_import
-
 import gettext
 import locale
 import os
 import re
 import sys
+import platform
 
 from bleachbit import Log
+from configparser import RawConfigParser, NoOptionError, SafeConfigParser
 
-#
-# Config Parser got renamed in Python 3
-#
-if sys.version_info >= (3, 0):
-    from configparser import RawConfigParser, NoOptionError, SafeConfigParser
-else:
-    from ConfigParser import RawConfigParser, NoOptionError, SafeConfigParser
-
-
-APP_VERSION = "3.2.0"
+APP_VERSION = "4.0.0"
 APP_NAME = "BleachBit"
 APP_URL = "https://www.bleachbit.org"
 
 socket_timeout = 10
 
+if sys.version_info < (3,0,0):
+    print('BleachBit no longer supports Python 2.x.')
+    sys.exit(1)
+
+if hasattr(sys, 'frozen') and sys.frozen == 'windows_exe':
+    stdout_encoding = 'utf-8'
+else:
+    stdout_encoding = sys.stdout.encoding
+    if 'win32' == sys.platform:
+        import win_unicode_console
+        win_unicode_console.enable()
+
+if not hasattr(platform, 'linux_distribution'):
+    from ._platform import _linux_distribution
+    platform.linux_distribution = _linux_distribution
+
 logger = Log.init_log()
 
 # Setting below value to false disables update notification (useful
@@ -61,12 +68,10 @@ online_update_notification_enabled = True
 bleachbit_exe_path = None
 if hasattr(sys, 'frozen'):
     # running frozen in py2exe
-    bleachbit_exe_path = os.path.dirname(
-        sys.executable.decode(sys.getfilesystemencoding()))
+    bleachbit_exe_path = os.path.dirname(sys.executable)
 else:
     # __file__ is absolute path to __init__.py
-    bleachbit_exe_path = os.path.dirname(os.path.dirname(
-        __file__.decode(sys.getfilesystemencoding())))
+    bleachbit_exe_path = os.path.dirname(os.path.dirname(__file__))
 
 # license
 license_filename = None
@@ -83,92 +88,11 @@ for lf in license_filenames:
         license_filename = lf
         break
 
-
-# os.path.expandvars does not work well with non-ascii Windows paths.
-# This is a unicode-compatible reimplementation of that function.
-# Note that if there are errors in the encoding it returns just expanded str.
-def expandvars(var):
-    """Expand environment variables.
-
-    Return the argument with environment variables expanded. Substrings of the
-    form $name or ${name} or %name% are replaced by the value of environment
-    variable name."""
-    if isinstance(var, str):
-        try:
-            final = var.decode('utf-8')
-        except UnicodeDecodeError:
-            # Keep a string which won't be expanded under Windows 7.
-            final = var
-    else:
-        final = var
-
-    if 'posix' == os.name:
-        final = os.path.expandvars(final)
-    elif 'nt' == os.name:
-        import _winreg
-        if final.startswith('${'):
-            final = re.sub(r'\$\{(.*?)\}(?=$|\\)',
-                           lambda x: '%%%s%%' % x.group(1),
-                           final)
-        elif final.startswith('$'):
-            final = re.sub(r'\$(.*?)(?=$|\\)',
-                           lambda x: '%%%s%%' % x.group(1),
-                           final)
-        try:
-            final = _winreg.ExpandEnvironmentStrings(final)
-        except TypeError:
-            # An error occurs when filename contains invalid
-            # char and we return string instead of unicode.
-            # This can happen on win7.
-            pass
-
-    return final
-
-# Windows paths have to be unicode, but os.path.expanduser does not support it.
-# This is a unicode-compatible reimplementation of that function.
-
-
-def expanduser(path):
-    """Expand the path with the home directory.
-
-    Return the argument with an initial component of "~" replaced by
-    that user's home directory.
-    """
-    if isinstance(path, str):
-        final = path.decode('utf-8')
-    else:
-        final = path
-
-    # If does not begin with tilde, do not alter.
-    if len(path) == 0 or not '~' == path[0]:
-        return final
-
-    if 'posix' == os.name:
-        final = os.path.expanduser(final)
-    elif 'nt' == os.name:
-        found = False
-        for env in [u'%USERPROFILE%', u'%HOME%']:
-            if env in os.environ:
-                home = expandvars(env)
-                found = True
-                break
-        if not found:
-            h_drive = expandvars(u'%HOMEDRIVE%')
-            h_path = expandvars(u'%HOMEPATH%')
-            home = os.path.join(h_drive, h_path)
-        final = final.replace('~user/', '')
-        final = final.replace('~/', '')
-        final = final.replace('~\\', '')
-        final = final.replace('~', '')
-        final = os.path.join(home, final)
-    return final
-
-
 # configuration
 portable_mode = False
 options_dir = None
 if 'posix' == os.name:
-    options_dir = expanduser("~/.config/bleachbit")
+    options_dir = os.path.expanduser("~/.config/bleachbit")
 elif 'nt' == os.name:
     if os.path.exists(os.path.join(bleachbit_exe_path, 'bleachbit.ini')):
         # portable mode
@@ -176,7 +100,7 @@ elif 'nt' == os.name:
         options_dir = bleachbit_exe_path
     else:
         # installed mode
-        options_dir = expandvars(r"${APPDATA}\BleachBit")
+        options_dir = os.path.expandvars(r"${APPDATA}\BleachBit")
 options_file = os.path.join(options_dir, "bleachbit.ini")
 
 # check whether the application is running from the source tree
@@ -190,7 +114,10 @@ if not portable_mode:
 personal_cleaners_dir = os.path.join(options_dir, "cleaners")
 
 # system cleaners
-if os.path.isdir(os.path.join(bleachbit_exe_path, 'cleaners')):
+# On Windows in portable mode, the bleachbit_exe_path is equal to
+# options_dir, so be careful that system_cleaner_dir is not set to
+# personal_cleaners_dir.
+if os.path.isdir(os.path.join(bleachbit_exe_path, 'cleaners')) and not portable_mode:
     system_cleaners_dir = os.path.join(bleachbit_exe_path, 'cleaners')
 elif sys.platform.startswith('linux') or sys.platform == 'darwin':
     system_cleaners_dir = '/usr/share/bleachbit/cleaners'
@@ -210,6 +137,9 @@ local_cleaners_dir = None
 if portable_mode:
     local_cleaners_dir = os.path.join(bleachbit_exe_path, 'cleaners')
 
+# windows10 theme
+windows10_theme_path = os.path.normpath(os.path.join(bleachbit_exe_path, 'themes/windows10'))
+
 # application icon
 __icons = (
     '/usr/share/pixmaps/bleachbit.png',  # Linux
@@ -257,7 +187,6 @@ else:
 #
 # gettext
 #
-FSE = sys.getfilesystemencoding()
 try:
     (user_locale, encoding) = locale.getdefaultlocale()
 except:
@@ -276,10 +205,10 @@ try:
     if not os.path.exists(locale_dir):
         raise RuntimeError('translations not installed')
     t = gettext.translation('bleachbit', locale_dir)
-    _ = t.ugettext
+    _ = t.gettext
 except:
     def _(msg):
-        """Dummy replacement for ugettext"""
+        """Dummy replacement for gettext"""
         return msg
 
 try:
@@ -295,12 +224,8 @@ except AttributeError:
             pass
         else:
             # bindtextdomain can not handle Unicode
-            if isinstance(locale_dir, unicode):
-                path = locale_dir.encode('utf-8')
-            else:
-                path = locale_dir
-            libintl.bindtextdomain('bleachbit', path)
-            libintl.bind_textdomain_codeset('bleachbit', 'UTF-8')
+            libintl.bindtextdomain(b'bleachbit', locale_dir.encode('utf-8'))
+            libintl.bind_textdomain_codeset(b'bleachbit', b'UTF-8')
 except:
     logger.exception('error binding text domain')
 
@@ -314,23 +239,6 @@ except:
         return plural
 
 
-#
-# string decoding
-#
-# In Python 2, some strings such as Python exceptions may be localized
-# and byte encoded.  This decodes them into Unicode.
-# See <https://bugs.launchpad.net/bleachbit/+bug/1416640>.
-#
-def decode_str(s):
-    """Decode a string into Unicode using the default encoding"""
-    if isinstance(s, Exception):
-        # for convenience
-        return decode_str(s.message)
-    try:
-        return s.decode(encoding)
-    except:
-        return s.decode('ascii', 'replace')
-
 #
 # pgettext
 #
@@ -392,6 +300,6 @@ if 'posix' == os.name:
         'XDG_CONFIG_HOME': os.path.expanduser('~/.config'),
         'XDG_CACHE_HOME': os.path.expanduser('~/.cache')
     }
-    for varname, value in envs.iteritems():
+    for varname, value in envs.items():
         if not os.getenv(varname):
             os.environ[varname] = value
